---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Minimal script
2. Describe error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**
 - OS: [e.g. iOS]
 - Local environment (e.g. virtual environment, conda environment)
 - Python version
 - Installed packages (e.g. "locan show_versions")

**Additional context**
Add any other context about the problem here.
